From: "Antonino A. Daplas" <adaplas@hotpop.com>
To: Andrew Morton <akpm@osdl.org>, adaplas@pol.net
Cc: linux-fbdev-devel@lists.sourceforge.net
Subject: Re: Re: [PATCH 1/6] nvidiafb: ioremap and i2c fixes
Date: Mon, 25 Apr 2005 11:21:20 +0800 [thread overview]
Message-ID: <200504251121.20530.adaplas@hotpop.com> (raw)
In-Reply-To: <20050423174013.3006852f.akpm@osdl.org>
On Sunday 24 April 2005 08:40, Andrew Morton wrote:
> "Antonino A. Daplas" <adaplas@hotpop.com> wrote:
> > - Add 'vram' option to specify amount of video RAM to remap
> > - Limit remap size to 128 MIB
>
> Am I right in believing that if someone has a 256MB card and doesn't know
> about the `vram' option, their card will fail to work, because the 128MB
> vmalloc() will fail?
>
I thought that a 128MiB vmalloc will work.
> If so, that seems a bit user-hostile to me. Perhaps we should make it
> 64MB?
Okay, dropping maximum to 64 MiB.
From: Antonino Daplas <adaplas@pol.net>
Signed-off-by: Antonino Daplas <adaplas@pol.net>
nvidia.c | 6 +++---
1 files changed, 3 insertions(+), 3 deletions(-)
diff -Nru a/drivers/video/nvidia/nvidia.c b/drivers/video/nvidia/nvidia.c
--- a/drivers/video/nvidia/nvidia.c 2005-04-16 11:54:44 +08:00
+++ b/drivers/video/nvidia/nvidia.c 2005-04-25 10:39:45 +08:00
@@ -1511,9 +1511,9 @@
if (vram && vram * 1024 * 1024 < par->FbMapSize)
par->FbMapSize = vram * 1024 * 1024;
- /* Limit amount of vram to 128 MB */
- if (par->FbMapSize > 128 * 1024 * 1024)
- par->FbMapSize = 128 * 1024 * 1024;
+ /* Limit amount of vram to 64 MB */
+ if (par->FbMapSize > 64 * 1024 * 1024)
+ par->FbMapSize = 64 * 1024 * 1024;
par->FbUsableSize = par->FbMapSize - (128 * 1024);
par->ScratchBufferSize = (par->Architecture < NV_ARCH_10) ? 8 * 1024 :
-------------------------------------------------------
SF email is sponsored by - The IT Product Guide
Read honest & candid reviews on hundreds of IT Products from real users.
Discover which products truly live up to the hype. Start reading now.
http://ads.osdn.com/?ad_id=6595&alloc_id=14396&op=click
next prev parent reply other threads:[~2005-04-25 3:25 UTC|newest]
Thread overview: 7+ messages / expand[flat|nested] mbox.gz Atom feed top
2005-04-16 5:13 [PATCH 1/6] nvidiafb: ioremap and i2c fixes Antonino A. Daplas
2005-04-24 0:40 ` Andrew Morton
2005-04-25 3:21 ` Antonino A. Daplas [this message]
2005-04-25 5:00 ` Andrew Morton
2005-04-25 5:03 ` Randy.Dunlap
2005-04-25 5:36 ` Miles Lane
2005-04-25 14:51 ` Randy.Dunlap
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=200504251121.20530.adaplas@hotpop.com \
--to=adaplas@hotpop.com \
--cc=adaplas@pol.net \
--cc=akpm@osdl.org \
--cc=linux-fbdev-devel@lists.sourceforge.net \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.